﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;

namespace SimpleMonoGame
{
    class Game : Microsoft.Xna.Framework.Game
    {
        public GraphicsDeviceManager graphics;
        private SpriteBatch batch;

        public Texture2D texture;
        private static Random random = new Random();
        private List<GameObject> gameObjects = new List<GameObject>();

        // Game Constructor
        public Game() : base()
        {
            // Display Window Setup
            graphics = new GraphicsDeviceManager(this);
            graphics.IsFullScreen = true;
            DisplayMode displayMode = GraphicsAdapter.DefaultAdapter.CurrentDisplayMode;
            graphics.PreferredBackBufferWidth = 1920;
            graphics.PreferredBackBufferHeight = 1080;
            graphics.SynchronizeWithVerticalRetrace = true;
            graphics.PreferMultiSampling = true;
            graphics.HardwareModeSwitch = true;
            IsMouseVisible = true;
        }

        // Load Content
        protected override void LoadContent()
        {
            batch = new SpriteBatch(GraphicsDevice);

            // Set texture to solid white color
            //texture = new Texture2D(GraphicsDevice, 1, 1);
            //texture.SetData(new[] { Color.White });

            // Set texture to image using a file stream
            FileStream setStream = File.Open(@"images/mario_sun.png", FileMode.Open);
            texture = Texture2D.FromStream(GraphicsDevice, setStream);
            setStream.Dispose();

            for (int i = 0; i < 100; i++)
            {
                GameObject gameObject = new GameObject();
                gameObject.texture = texture;
                gameObjects.Add(gameObject);
            }
        }

        // Update
        protected override void Update(GameTime gameTime)
        {

            for (int i = 0; i < gameObjects.Count; i++)
            {
                gameObjects[i].Update();
            }

            if (Keyboard.GetState().IsKeyDown(Keys.Escape))
            {
                Program.game.Exit();
            }
            
        }

        // Draw
        protected override void Draw(GameTime gameTime)
        {
            // Background Clear Color
            GraphicsDevice.Clear(Color.LightBlue);

            // Sprite Batch
            batch.Begin();

            //batch.Draw(texture, new Rectangle(1, 1, 32, 32), Color.Red);
            //batch.Draw(texture, new Rectangle(32, 1, 32, 32), Color.Blue);

            foreach (GameObject gameObject in gameObjects)
            {
                batch.Draw(gameObject.texture, gameObject.position, gameObject.color);
            }

            /*for (int i = 0; i < 20; i++)
            {
                //Color color = new Color(new Vector3((float)random.NextDouble() * (1 - 0) + 0, (float)random.NextDouble() * (1 - 0) + 0, (float)random.NextDouble() * (1 - 0) + 0));
                batch.Draw(texture, new Rectangle(random.Next(-64, 1920), random.Next(-64, 1080), random.Next(1, 80), random.Next(1, 80)), Color.Black);
            }*/

            batch.End();
        }

        // Unload
        protected override void UnloadContent()
        {
            batch.Dispose();
        }
    } 
}
